import { connect, Dispatch } from 'react-redux';
import {
  SensorItemTree,
  SensorItemTreeStateProps,
  SensorItemTreeDispatchProps,
} from './components/SensorItemTree';
import State from '../redux/state/SensorItemReadAll';

import * as SensorItemReadAllByActions from '../redux/action/sensor_item_read_all';
import * as SensorItemReadAllBySensorActions from '../redux/action/sensor_item_read_all_by_sensor';
import * as SensorItemTypeReadAllActions from '../redux/action/sensor_item_type_read_all';
import * as SensorItemKeyReadAllByCrawlerActions from '../redux/action/sensor_item_key_read_all_by_crawler';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';

import Sensor from '@overflow/sensor/api/model/Sensor';
import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';


export function mapStateToProps(state: any, props: any): SensorItemTreeStateProps {
  return {
    crawlerId: props.crawlerId,
    // metaSensorItemTypeList: state.MetaSensorItemTypeList,
    // sensorItemList: state.SensorItemList,
    // metaSensorItemList: state.MetaSensorItemList,
    metaSensorItemKeyList: state.MetaSensorItemKeyList,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): SensorItemTreeDispatchProps {
  return {
    onReadAll: () => {
      dispatch(asyncRequestActions.request('MetaSensorItemService', 'readAll', SensorItemReadAllByActions.REQUEST));
    },
    onReadAllBySensor: (sensor: Sensor) => {
      dispatch(asyncRequestActions.request('SensorItemService', 'readAllBySensor',
                                           SensorItemReadAllBySensorActions.REQUEST, JSON.stringify(sensor)));
    },
    onSensorItemTypeReadAll: () => {
      dispatch(asyncRequestActions.request('MetaSensorItemTypeService', 'readAll', SensorItemTypeReadAllActions.REQUEST));
    },
    onReadAllSensorItemKeyByCrawler: (metaCrawler: MetaCrawler) => {
      dispatch(asyncRequestActions.request('MetaSensorItemKeyService', 'readAllByCrawler',
                                           SensorItemKeyReadAllByCrawlerActions.REQUEST, JSON.stringify(metaCrawler)));
    },
  };
}


export default connect(mapStateToProps, mapDispatchToProps)(SensorItemTree);
