import * as React from 'react';
import {
  Table,
  Checkbox,
  Button,
  Header,
  Container,
  Modal,
  Icon,
  List,
} from 'semantic-ui-react';
import NoAuthProbe from '@overflow/noauthprobe/api/model/NoAuthProbe';
import Domain from '@overflow/domain/api/model/Domain';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import * as Utils from '@overflow/commons/util/Utils';
import * as JSONPretty from 'react-json-pretty';

export interface StateProps {
  noauthList?: NoAuthProbe[];
}

export interface DispatchProps {
  onReadAllByDomain?(domain: Domain): void;
  acceptNoAuthProbe?(noauthProbe: NoAuthProbe): void;
  denyNoAuthProbe?(noauthProbe: NoAuthProbe): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: NoAuthProbe;
  modalVisible: boolean;
  actionDisabled: boolean;
  isDeny: boolean;
}

export class NoauthProbeList extends React.Component<Props, State> {

  private data: any;

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: null,
      modalVisible: false,
      actionDisabled: true,
      isDeny: false,
    };
  }

  public componentWillMount(): void {
    let domain: Domain = {
      id: 1,
    };
    this.props.onReadAllByDomain(domain);
  }

  public handleSelect(probe: NoAuthProbe): void {
    // let idx = this.selectedIds.indexOf(probe);
    // if (idx === -1) {
    //   this.selectedIds.push(probe);
    // } else {
    //   this.selectedIds.splice(idx, 1);
    // }
    this.setState({
      selected: probe,
    });
  }

  // tslint:disable-next-line:no-empty
  public handleSearch = (result: any[]): void => {
  }

  // public checkExist(probe: NoAuthProbe): boolean {
  //   if (this.state.selected.indexOf(probe) === -1) {
  //     return false;
  //   }
  //   return true;
  // }

  public handleActionDisable(): boolean {
    if (this.state.selected === null) {
      return true;
    }
    return false;
  }

  public handleConfirm(): void {
    if (this.state.isDeny) {
      console.log('Denied.');
      this.props.denyNoAuthProbe(this.state.selected);
    } else {
      console.log('Accepted.');
      this.props.acceptNoAuthProbe(this.state.selected);
    }
    this.setState({
      modalVisible: false,
    });
  }

  public handleDeny(): void {
    this.setState({
      isDeny: true,
      modalVisible: true,
    });
  }

  public handleRowActive(probe: NoAuthProbe): boolean {
    if (this.state.selected === probe) {
      return true;
    }
    return false;
  }

  public render(): JSX.Element {
    let noauth =
      <Container fluid>
        <Table celled selectable>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Description</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created At</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>API Key</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderRows()}
          </Table.Body>
        </Table>
        {/* <Button primary disabled={this.state.actionDisabled} */}
        <Button primary disabled={this.handleActionDisable()}
          floated={'right'} onClick={() => this.setState({ modalVisible: true, isDeny: false })}>
          Accept
        </Button>
        <Button disabled={this.handleActionDisable()} floated={'right'}
          onClick={() => this.setState({ modalVisible: true, isDeny: true })}>
          Deny
        </Button>

        <Modal size='tiny'
          open={this.state.modalVisible}
        >
          <Header icon='certificate' content='Confirm' />
          <Modal.Content>
            Are you sure?
          </Modal.Content>
          <Modal.Actions>
            <Button color='red' onClick={() => this.setState({ modalVisible: false })}>
              <Icon name='remove' /> No
            </Button>
            <Button color='green' onClick={this.handleConfirm.bind(this)} >
              <Icon name='checkmark' /> Yes
            </Button>
          </Modal.Actions>
        </Modal>
      </Container>;
    return (
      <ListContainer
        contents={noauth}
        data={this.props.noauthList}
        onSearch={this.handleSearch}
        filter={null}
      />
    );
  }

  private renderRows(): (JSX.Element | JSX.Element[]) {
    if (this.props.noauthList === undefined) {
      return null;
    }

    if (this.props.noauthList.length === 0) {
      return <Table.Row error >
        <Table.Cell textAlign='center' colSpan='4'>No results found.</Table.Cell>
      </Table.Row>;
    }

    let elem: Array<JSX.Element> = new Array();

    this.props.noauthList.map((probe: NoAuthProbe, index: number) => {

      let map: any = JSON.parse(probe.description);

      let addressArray: string[] = map.network.address.split('|', 2);
      let ipv4: string = addressArray[0];
      let ipv6: string = addressArray[1];
      map.network.ipv4 = ipv4;
      map.network.ipv6 = ipv6;

      delete map.network.address;

      elem.push(
        <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)} active={this.handleRowActive(probe)}>
          <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
          {/*<Table.Cell textAlign={'center'}>ipv4 - {ipv4} <br/> ipv6 - {ipv6}</Table.Cell>
          <Table.Cell textAlign={'center'}>{map.network.macAddress}</Table.Cell>
          <Table.Cell>{map.host.name}</Table.Cell>*/}
          < Table.Cell fontSize='2' > <JSONPretty json={JSON.stringify(map)} /></Table.Cell >
          <Table.Cell textAlign={'center'}>{Utils.date2date(probe.createDate)}</Table.Cell>
          <Table.Cell textAlign={'center'}>{probe.apiKey}</Table.Cell>
        </Table.Row >,
      );

    });

    return elem;
  }
}

